# Chat Session Export

**Project:** canvas-mcp
**Session ID:** test-session
**Working Directory:** /Users/vishal/Desktop/canvas-mcp
**End Reason:** manual-test
**Exported:** 2025-10-04T13:08:11.197407

---

### [12:00:00] User
test message

